@@ -41,6 +41,7 @@ setGeneric("rowWeightedMads", function(x, w = NULL, rows = NULL, cols = NULL, na
 )
 
 .matrixStats_rowWeightedMads <- function(x, w = NULL, rows = NULL, cols = NULL, na.rm = FALSE,  constant = 1.4826, center = NULL, ..., useNames = TRUE){
+  center <- normarg_center(center, nrow(x), "nrow(x)")
   matrixStats::rowWeightedMads(x, w = w, rows = rows, cols = cols, na.rm = na.rm, constant = constant, center = center, ..., useNames = useNames)
 }
 
@@ -62,6 +63,7 @@ setGeneric("colWeightedMads", function(x, w = NULL, rows = NULL, cols = NULL, na
 )
 
 .matrixStats_colWeightedMads <- function(x, w = NULL, rows = NULL, cols = NULL, na.rm = FALSE,  constant = 1.4826, center = NULL, ..., useNames = TRUE){
+  center <- normarg_center(center, ncol(x), "ncol(x)")
   matrixStats::colWeightedMads(x, w = w, rows = rows, cols = cols, na.rm = na.rm, constant = constant, center = center, ..., useNames = useNames)
 }
 
